==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotGridColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridColumnDescription } from "./WebPivotGridColumnDescription";
/**
 * @hidden
 */
var WebPivotGridColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridColumnDescriptionMetadata, _super);
    function WebPivotGridColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridColumnDescriptionMetadata.b = function (a) {
        if (WebPivotGridColumnDescriptionMetadata.a == null) {
            WebPivotGridColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridColumnDescriptionMetadata.c(WebPivotGridColumnDescriptionMetadata.a);
        }
        if (a.j(WebPivotGridColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotGridColumnDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebPivotGridColumnDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotGridColumn");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Field", "String");
        a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
        a.item("Value", "ExportedType:WebPivotValue");
    };
    WebPivotGridColumnDescriptionMetadata.d = function (a) {
        WebPivotGridColumnDescriptionMetadata.b(a);
        a.aa("WebPivotGridColumn", function () { return new WebPivotGridColumnDescription(); });
        a.z("WebPivotGridColumn", WebPivotGridColumnDescriptionMetadata.a);
    };
    WebPivotGridColumnDescriptionMetadata.$t = markType(WebPivotGridColumnDescriptionMetadata, 'WebPivotGridColumnDescriptionMetadata');
    WebPivotGridColumnDescriptionMetadata.a = null;
    return WebPivotGridColumnDescriptionMetadata;
}(Base));
export { WebPivotGridColumnDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotGridColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridColumnDescription } from "./WebPivotGridColumnDescription";
/**
 * @hidden
 */
var WebPivotGridColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridColumnDescriptionMetadata, _super);
    function WebPivotGridColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridColumnDescriptionMetadata.b = function (a) {
        if (WebPivotGridColumnDescriptionMetadata.a == null) {
            WebPivotGridColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridColumnDescriptionMetadata.c(WebPivotGridColumnDescriptionMetadata.a);
        }
        if (a.k(WebPivotGridColumnDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotGridColumnDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebPivotGridColumnDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotGridColumn");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Field", "String");
        a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
        a.item("Value", "ExportedType:WebPivotValue");
    };
    WebPivotGridColumnDescriptionMetadata.d = function (a) {
        WebPivotGridColumnDescriptionMetadata.b(a);
        a.ac("WebPivotGridColumn", function () { return new WebPivotGridColumnDescription(); });
        a.ab("WebPivotGridColumn", WebPivotGridColumnDescriptionMetadata.a);
    };
    WebPivotGridColumnDescriptionMetadata.$t = markType(WebPivotGridColumnDescriptionMetadata, 'WebPivotGridColumnDescriptionMetadata');
    WebPivotGridColumnDescriptionMetadata.a = null;
    return WebPivotGridColumnDescriptionMetadata;
}(Base));
export { WebPivotGridColumnDescriptionMetadata };
